@@ -1,12 +1,12 @@
 import time
 import logging
 
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 
 
 class LogEmitter(GObject.GObject):
     __gsignals__ = {
-        "logged": (GObject.SignalFlags.RUN_FIRST, None, (object, ))
+        "logged": (GObject.SignalFlags.RUN_FIRST, None, (object,))
     }  # list of (str, float, str, int)
 
     def __init__(self):
@@ -25,13 +25,18 @@ class GLogHandler(logging.Handler):
         self.emitter = emitter
 
     def emit(self, record):
-        message = self.format(record)
-        if self.emitter.messages is not None:
-            self.emitter.messages.append((record.task, time.time(), message,
-                                          record.levelno))
+        def _emit(record):
+            message = self.format(record)
+            if self.emitter.messages is not None:
+                self.emitter.messages.append(
+                    (record.task, time.time(), message, record.levelno)
+                )
 
-        self.emitter.emit("logged",
-                          (record.task, time.time(), message, record.levelno))
+            self.emitter.emit(
+                "logged", (record.task, time.time(), message, record.levelno)
+            )
+
+        GLib.idle_add(_emit, record)
 
 
 logemitter = LogEmitter()
